@@ -37,7 +37,7 @@ def get_cdata(elem, path):
     return cdata
 
 def clean_data(msg):
-    return msg.replace('<p>','').replace('</p>','').replace('<br />','').strip(" \n")
+    return msg.replace('<p>','').replace('</p>','').replace('<br />','\n').strip(" \n")
     #return msg
 
 def get_case(elem):
